simd_aligned

Struct u16x8

#[repr(C, align(16))]
pub struct u16x8 { /* private fields */ }

Implementations

Source

impl u16x8

pub const ONE: u16x8 = _

pub const ZERO: u16x8 = _

pub const MAX: u16x8 = _

pub const MIN: u16x8 = _

pub const LANES: u16 = 8u16

The number of lanes in this SIMD vector.

pub const BITS: u16 = 128u16

The size of this SIMD vector in bits.

Source

impl u16x8

pub fn new(array: [u16; 8]) -> u16x8

pub fn cmp_eq(self, rhs: u16x8) -> u16x8

pub fn blend(self, t: u16x8, f: u16x8) -> u16x8

pub fn max(self, rhs: u16x8) -> u16x8

pub fn min(self, rhs: u16x8) -> u16x8

pub fn saturating_add(self, rhs: u16x8) -> u16x8

pub fn saturating_sub(self, rhs: u16x8) -> u16x8

pub fn from_u8x16_low(u: u8x16) -> u16x8

Unpack the lower half of the input and zero expand it to u16 values.

pub fn from_u8x16_high(u: u8x16) -> u16x8

Unpack the upper half of the input and zero expand it to u16 values.

pub fn mul_widen(self, rhs: u16x8) -> u32x8

multiplies two u16x8 and returns the result as a widened u32x8

pub fn mul_keep_high(self, rhs: u16x8) -> u16x8

Multiples two u16x8 and return the high part of intermediate u32x8

pub fn to_array(self) -> [u16; 8]

pub fn as_array_ref(&self) -> &[u16; 8]

pub fn as_array_mut(&mut self) -> &mut [u16; 8]

Source

impl u16x8

pub fn splat(elem: u16) -> u16x8